// Copyright Shreevatsa R, 2011.
// Licenced under the GPL, version 2 or later.
// http://www.gnu.org/licenses/gpl-2.0.txt

var alphabets = {

    'devanagari': {
        'vowels' : ['अ', 'आ', 'इ', 'ई', 'उ', 'ऊ',
                    'ऋ', 'ॠ', 'ऌ', 'ॡ',
                    'ऎ', 'ए', 'ऐ',
                    'ऒ', 'ओ', 'औ'],
        'matras' : ['', 'ा', 'ि', 'ी', 'ु', 'ू',
                    'ृ', 'ॄ', 'ॢ', 'ॣ',
                    'ॆ', 'े', 'ै',
                    'ॊ', 'ो', 'ौ'],
        'consonants' : ['क', 'ख', 'ग', 'घ', 'ङ',
                        'च', 'छ', 'ज', 'झ', 'ञ',
                        'ट', 'ठ', 'ड', 'ढ', 'ण',
                        'त', 'थ', 'द', 'ध', 'न',
                        'प', 'फ', 'ब', 'भ', 'म',
                        'य', 'र', 'ल', 'व',
                        'श', 'ष', 'स', 'ह', 'ळ'],
        'symbols' : ['ं', 'ः', 'ऽ', '।', '॥',
                     '०', '१', '२', '३', '४', '५', '६', '७', '८', '९'],
        'virama' : '्'
    },

    'harvardkyoto': {
        'vowels': ['a', 'A', 'i', 'I', 'u', 'U',
                   'R', 'RR', 'lR', 'lRR',
                   'e', 'E', 'ai',
                   'o', 'O', 'au'],
        'symbols' : ['M', 'H', '\'', '.', '..',
                     '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
        'consonants' : ['k', 'kh', 'g', 'gh', 'G',
                        'c', 'ch', 'j', 'jh', 'J',
                        'T', 'Th', 'D', 'Dh', 'N',
                        't', 'th', 'd', 'dh', 'n',
                        'p', 'ph', 'b', 'bh', 'm',
                        'y', 'r', 'l', 'v',
                        'z', 'S', 's', 'h', 'L']
    },

    'itrans': {
        'vowels' : ['a', ['aa','A'], 'i', ['ii','I'], 'u', ['uu','U'],
                    ['RRi','R^i'], ['RRI','R^I'], ['LLi','L^i'], ['LLI','L^I'],
                    'e', 'E', 'ai',
                    'o', 'O', 'au'],
        'symbols' : ['M', 'H', '\'', '|', '||',
                     '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
        'consonants' : ['k', 'kh', 'g', 'gh', ['~N','N^'],
                        'ch', 'Ch', 'j', 'jh', ['~n','JN'],
                        'T', 'Th', 'D', 'Dh', 'N',
                        't', 'th', 'd', 'dh', 'n',
                        'p', 'ph', 'b', 'bh', 'm',
                        'y', 'r', 'l', ['v','w'],
                        'sh', 'Sh', 's', 'h', 'L']
    },

    'velthuis': {
        'vowels' : ['a', 'aa', 'i', 'ii', 'u', 'uu',
                    '.r', '.rr', '.l', '.ll',
                    'e', 'ee', 'ai',
                    'o', 'oo', 'au'],
        'symbols' : ['.m', '.h', '\'', '|', '||',
                     '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
        'consonants' : ['k', 'kh', 'g', 'gh', '"n',
                        'c', 'ch', 'j', 'jh', '~n',
                        '.t', '.th', '.d', '.dh', '.n',
                        't', 'th', 'd', 'dh', 'n',
                        'p', 'ph', 'b', 'bh', 'm',
                        'y', 'r', 'l', 'v',
                        '"s', '.s', 's', 'h', '..l']
    },

    'iso': {
        'vowels' : ['a', 'ā', 'i', 'ī', 'u', 'ū',
                    'r̥', 'r̥̄', 'l̥', 'l̥̄',
                    'e', 'ē', 'ai',
                    'o', 'ō', 'au'],
        'symbols' : ['ṁ', 'ḥ', '\'', '|', '||',
                     '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
        'consonants' : ['k', 'kh', 'g', 'gh', 'ṅ',
                        'c', 'ch', 'j', 'jh', 'ñ',
                        'ṭ', 'ṭh', 'ḍ', 'ḍh', 'ṇ',
                        't', 'th', 'd', 'dh', 'n',
                        'p', 'ph', 'b', 'bh', 'm',
                        'y', 'r', 'l', 'v',
                        'ś', 'ṣ', 's', 'h', 'ḷ']
    },

    'ISO': {
        'vowels' : ['A', 'Ā', 'I', 'Ī', 'U', 'Ū',
                    'R̥', 'R̥̄', 'L̥', 'L̥̄',
                    'E', 'Ē', 'AI',
                    'O', 'Ō', 'AU'],
        'symbols' : ['Ṁ', 'Ḥ', '\'', '|', '||',
                     '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
        'consonants' : ['K', 'Kh', 'G', 'Gh', 'Ṅ',
                        'C', 'Ch', 'J', 'Jh', 'Ñ',
                        'Ṭ', 'Ṭh', 'Ḍ', 'Ḍh', 'Ṇ',
                        'T', 'Th', 'D', 'Dh', 'N',
                        'P', 'Ph', 'B', 'Bh', 'M',
                        'Y', 'R', 'L', 'V',
                        'Ś', 'Ṣ', 'S', 'H', 'Ḷ']
    },

    'kannada': {
        'vowels' : ['ಅ', 'ಆ', 'ಇ', 'ಈ', 'ಉ', 'ಊ',
                    'ಋ', 'ೠ', 'ಌ', 'ೡ',
                    'ಎ', 'ಏ', 'ಐ',
                    'ಒ', 'ಓ', 'ಔ'],
        'matras' : ['', 'ಾ', 'ಿ', 'ೀ', 'ು', 'ೂ',
                    'ೃ', 'ೄ', 'ೢ', 'ೣ',
                    'ೆ', 'ೇ', 'ೈ',
                    'ೊ', 'ೋ', 'ೌ'],
        'symbols' : ['ಂ', 'ಃ', 'ಽ', '।', '॥',
                     '೦', '೧', '೨', '೩', '೪', '೫', '೬', '೭', '೮', '೯'],
        'consonants' : ['ಕ', 'ಖ', 'ಗ', 'ಘ', 'ಙ',
                        'ಚ', 'ಛ', 'ಜ', 'ಝ', 'ಞ',
                        'ಟ', 'ಠ', 'ಡ', 'ಢ', 'ಣ',
                        'ತ', 'ಥ', 'ದ', 'ಧ', 'ನ',
                        'ಪ', 'ಫ', 'ಬ', 'ಭ', 'ಮ',
                        'ಯ', 'ರ', 'ಲ', 'ವ',
                        'ಶ', 'ಷ', 'ಸ', 'ಹ', 'ಳ'],
        'virama' : '್'
    },
};

