// Copyright Shreevatsa R, 2011.
// Licenced under the GPL, version 2 or later.
// http://www.gnu.org/licenses/gpl-2.0.txt

/*
Transliteration between Indian languages and transliteration schemes.
*/

if(!this.INtranslit) {
    //To avoid creating global variables put everything in a "closure", returning only things that need to be "global"
    this.INtranslit = function () {
        //For non-Firebug users, console.log should do nothing (not give an error)
        //if(typeof(console) === "undefined" || typeof(console.log) === "undefined") var console = { log: function() { } };

        Array.prototype.contains = function(obj) {
          var i = this.length;
          while (i--) {
            if (this[i] === obj) {
              return true;
            }
          }
          return false;
        }

        // Make trie, given a table like {'a':'अ', 'A':'आ', 'ai':'ऐ', 'au':'औ' }
        function maketrie(table) {
            var root = {};
            for(var s in table) {
                //Go down the tree, following the letters of s
                var where = root;
                for(var i=0; i<s.length; ++i) {
                    if(where[s[i]] === undefined) where[s[i]] = {};
                    where = where[s[i]];
                }
                where.label = table[s];
            }
            return root;
        }

        //Convert a string using a labelled trie
        function convert(s, trie) {
            var out = '';
            //d = depth, a = parsed part, b = length of unparsed part
            var where = trie, d = 0, a = '', b = 0;
            var i = 0;
            while(i < s.length) {
                var c = s[i]; ++i;
                ++d;
                ++b;
                //If there is a child in the trie, just follow it
                if(where[c] !== undefined) {
                    where = where[c];
                    if(where.label !== undefined) {
                        a = where.label; b = 0;
                    }
                }
                // else, append current parsed part, and go back to the root
                else {
                    //If nothing has been parsed, declare the first character as parsed 
                    if(b==d) {
                        a = s[i-b];
                        --b;
                    }
                    out += a;
                    //Go back to unparsed, and start over. (TODO: here a KMP table would help)
                    i -= b;
                    where = trie; d = 0; a = ''; b = 0;
                }
            }
            out += a+s.substr(i-b);
            return out;
        }

        //////////////////////////////////////////////////////////////////////
        /* Make trie for converting from alphabet1 to alphabet2.
           An object like {'a':'अ', 'A':'आ', 'ai':'ऐ', 'au':'औ', 'k':'क्'}
           or like {'अ':'a', 'आ':'A', 'ऐ':'ai', 'औ':'au' }

           If both have matras or both don't, is straightforward.
           If alphabet1 has matras, must map
                     consonant+virama to consonant,
                     matra to vowel.
           If alphabet2 has matras, must map
                     consonant to consonant+virama
        */
        function inter_trie(alphabet1, alphabet2) {
            var ret = {};
            for(var type in alphabet1) {
                for(var i=0; i<alphabet1[type].length; ++i) {
                    var lhses = (typeof(alphabet1[type][i])=='string') ? [alphabet1[type][i]] : alphabet1[type][i];
                    for(var j=0; j<lhses.length; ++j) {
                        var lhs = lhses[j];
                        if(lhs==='') continue;
                        var rhs = (alphabet2[type]!==undefined ? alphabet2[type][i] : '');
                        if(typeof(rhs)!=='string') rhs = rhs[0];
                        if( (alphabet1['matras']!==undefined ) && (alphabet2['matras']===undefined) ) {
                            if(type=='consonants') lhs += alphabet1['virama'];
                            if(type=='matras') rhs = alphabet2['vowels'][i];
                        }
                        if( (alphabet1['matras']===undefined) && (alphabet2['matras']!==undefined) ) {
                            if(type=='consonants') rhs += alphabet2['virama'];
                        }
                        ret[lhs] = rhs;
                    }
                }
            }
            return maketrie(ret);
        }

        //////////////////////////////////////////////////////////////////////

        function fixmatras(s, alphabet) { //Replace क्इ            with                 कि
            if(alphabet['matras']===undefined) return s;
            for(var i=0; i<alphabet['vowels'].length; ++i) {
                s = s.replace(RegExp(alphabet['virama']+alphabet['vowels'][i], "g"), alphabet['matras'][i]);
            }
            return s;
        }

        function unfixmatras(s, alphabet) { //Replace कि            with                 क्इ
            if(alphabet['matras']===undefined) return s;
            //First, replace explicit matras with VIRAMA+VOWEL
            for(var i=1; i<alphabet['matras'].length; ++i) {
                var m = alphabet['matras'][i];
                s = s.replace(RegExp(m, "g"), alphabet['virama']+alphabet['vowels'][i]);
            }
            //Next, replace implicit 'a' with VIRAMA+A
            var t = '';
            for(var i=0; i<s.length; ++i) {
                t += s[i];
                if(alphabet['consonants'].contains(s[i]) && s[i+1]!==alphabet['virama']) { //Even if it is undefined!
                    t += alphabet['virama'] + alphabet['vowels'][0];
                }
            }
            return t;
        }
        
        //////////////////////////////////////////////////////////////////////

        //Ok, explanation: "u" is my canonical Unicode form, in which "ka" and "ki" are both stored as KA+VIRAMA+VOWEL.
        //This is convenient as "k" is always KA+VIRAMA, etc.
        //fixmatras() shows Devanagari, by replacing each VIRAMA+VOWEL with the matra for that vowel.
        //unfixmatras() converts Devanagari to u, by replacing each MATRA with VIRAMA+VOWEL.

        //TODO: Make this exhaustive without hundreds of lines of code
        function insertbraces(s) {
          //Insert braces in ai, au, aii, kh, gh, etc.
          s = s.replace(RegExp('अइ', "g"), 'अ{}इ');
          s = s.replace(RegExp('अउ', "g"), 'अ{}उ');
          return s;
        }

        function removebraces(s) {
          return s.replace(RegExp("{}", "g"), "");
        }


        var ret = {
            unfixmatras : unfixmatras,
            fixmatras : fixmatras,
            convert : convert,
            maketrie : maketrie,
        };

        for(var f in alphabets) {
            for(var g in alphabets) {
                if(f!==g) {
                    var t = function() {
                        ret['trie_'+f+'2'+g] = inter_trie(alphabets[f], alphabets[g]);
                    }();
                }
            }
        }

        return ret;
    }();
}
